# PyJanggi
PyJanggi is a Python library for a Korean chess called [Janggi](https://en.wikipedia.org/wiki/Janggi).
It provides functionalities to simulate a game, maintain a game board, list all possible moves, make a move, and validate a move.